@@ -984,3 +984,105 @@
 #define GLIB_AVAILABLE_ENUMERATOR_IN_2_80
 #define GLIB_AVAILABLE_TYPE_IN_2_80
 #endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_82
+#define GLIB_DEPRECATED_IN_2_82 GLIB_DEPRECATED
+#define GLIB_DEPRECATED_IN_2_82_FOR(f) GLIB_DEPRECATED_FOR (f)
+#define GLIB_DEPRECATED_MACRO_IN_2_82 GLIB_DEPRECATED_MACRO
+#define GLIB_DEPRECATED_MACRO_IN_2_82_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_82 GLIB_DEPRECATED_ENUMERATOR
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_82_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GLIB_DEPRECATED_TYPE_IN_2_82 GLIB_DEPRECATED_TYPE
+#define GLIB_DEPRECATED_TYPE_IN_2_82_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GLIB_DEPRECATED_IN_2_82 _GLIB_EXTERN
+#define GLIB_DEPRECATED_IN_2_82_FOR(f) _GLIB_EXTERN
+#define GLIB_DEPRECATED_MACRO_IN_2_82
+#define GLIB_DEPRECATED_MACRO_IN_2_82_FOR(f)
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_82
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_82_FOR(f)
+#define GLIB_DEPRECATED_TYPE_IN_2_82
+#define GLIB_DEPRECATED_TYPE_IN_2_82_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_82
+#define GLIB_AVAILABLE_IN_2_82 GLIB_UNAVAILABLE (2, 82)
+#define GLIB_AVAILABLE_STATIC_INLINE_IN_2_82 GLIB_UNAVAILABLE_STATIC_INLINE (2, 82)
+#define GLIB_AVAILABLE_MACRO_IN_2_82 GLIB_UNAVAILABLE_MACRO (2, 82)
+#define GLIB_AVAILABLE_ENUMERATOR_IN_2_82 GLIB_UNAVAILABLE_ENUMERATOR (2, 82)
+#define GLIB_AVAILABLE_TYPE_IN_2_82 GLIB_UNAVAILABLE_TYPE (2, 82)
+#else
+#define GLIB_AVAILABLE_IN_2_82 _GLIB_EXTERN
+#define GLIB_AVAILABLE_STATIC_INLINE_IN_2_82
+#define GLIB_AVAILABLE_MACRO_IN_2_82
+#define GLIB_AVAILABLE_ENUMERATOR_IN_2_82
+#define GLIB_AVAILABLE_TYPE_IN_2_82
+#endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_84
+#define GLIB_DEPRECATED_IN_2_84 GLIB_DEPRECATED
+#define GLIB_DEPRECATED_IN_2_84_FOR(f) GLIB_DEPRECATED_FOR (f)
+#define GLIB_DEPRECATED_MACRO_IN_2_84 GLIB_DEPRECATED_MACRO
+#define GLIB_DEPRECATED_MACRO_IN_2_84_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_84 GLIB_DEPRECATED_ENUMERATOR
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_84_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GLIB_DEPRECATED_TYPE_IN_2_84 GLIB_DEPRECATED_TYPE
+#define GLIB_DEPRECATED_TYPE_IN_2_84_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GLIB_DEPRECATED_IN_2_84 _GLIB_EXTERN
+#define GLIB_DEPRECATED_IN_2_84_FOR(f) _GLIB_EXTERN
+#define GLIB_DEPRECATED_MACRO_IN_2_84
+#define GLIB_DEPRECATED_MACRO_IN_2_84_FOR(f)
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_84
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_84_FOR(f)
+#define GLIB_DEPRECATED_TYPE_IN_2_84
+#define GLIB_DEPRECATED_TYPE_IN_2_84_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_84
+#define GLIB_AVAILABLE_IN_2_84 GLIB_UNAVAILABLE (2, 84)
+#define GLIB_AVAILABLE_STATIC_INLINE_IN_2_84 GLIB_UNAVAILABLE_STATIC_INLINE (2, 84)
+#define GLIB_AVAILABLE_MACRO_IN_2_84 GLIB_UNAVAILABLE_MACRO (2, 84)
+#define GLIB_AVAILABLE_ENUMERATOR_IN_2_84 GLIB_UNAVAILABLE_ENUMERATOR (2, 84)
+#define GLIB_AVAILABLE_TYPE_IN_2_84 GLIB_UNAVAILABLE_TYPE (2, 84)
+#else
+#define GLIB_AVAILABLE_IN_2_84 _GLIB_EXTERN
+#define GLIB_AVAILABLE_STATIC_INLINE_IN_2_84
+#define GLIB_AVAILABLE_MACRO_IN_2_84
+#define GLIB_AVAILABLE_ENUMERATOR_IN_2_84
+#define GLIB_AVAILABLE_TYPE_IN_2_84
+#endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_86
+#define GLIB_DEPRECATED_IN_2_86 GLIB_DEPRECATED
+#define GLIB_DEPRECATED_IN_2_86_FOR(f) GLIB_DEPRECATED_FOR (f)
+#define GLIB_DEPRECATED_MACRO_IN_2_86 GLIB_DEPRECATED_MACRO
+#define GLIB_DEPRECATED_MACRO_IN_2_86_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_86 GLIB_DEPRECATED_ENUMERATOR
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_86_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GLIB_DEPRECATED_TYPE_IN_2_86 GLIB_DEPRECATED_TYPE
+#define GLIB_DEPRECATED_TYPE_IN_2_86_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GLIB_DEPRECATED_IN_2_86 _GLIB_EXTERN
+#define GLIB_DEPRECATED_IN_2_86_FOR(f) _GLIB_EXTERN
+#define GLIB_DEPRECATED_MACRO_IN_2_86
+#define GLIB_DEPRECATED_MACRO_IN_2_86_FOR(f)
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_86
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_86_FOR(f)
+#define GLIB_DEPRECATED_TYPE_IN_2_86
+#define GLIB_DEPRECATED_TYPE_IN_2_86_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_86
+#define GLIB_AVAILABLE_IN_2_86 GLIB_UNAVAILABLE (2, 86)
+#define GLIB_AVAILABLE_STATIC_INLINE_IN_2_86 GLIB_UNAVAILABLE_STATIC_INLINE (2, 86)
+#define GLIB_AVAILABLE_MACRO_IN_2_86 GLIB_UNAVAILABLE_MACRO (2, 86)
+#define GLIB_AVAILABLE_ENUMERATOR_IN_2_86 GLIB_UNAVAILABLE_ENUMERATOR (2, 86)
+#define GLIB_AVAILABLE_TYPE_IN_2_86 GLIB_UNAVAILABLE_TYPE (2, 86)
+#else
+#define GLIB_AVAILABLE_IN_2_86 _GLIB_EXTERN
+#define GLIB_AVAILABLE_STATIC_INLINE_IN_2_86
+#define GLIB_AVAILABLE_MACRO_IN_2_86
+#define GLIB_AVAILABLE_ENUMERATOR_IN_2_86
+#define GLIB_AVAILABLE_TYPE_IN_2_86
+#endif
